Changelog
=========


2.0.1 (2021-11-01)
------------------

- Explicitly include dependencies (supporting pip installations)
  [ericof]

- Use **plone/setup-plone@v1.0.0** in Github actions
  [ericof]


2.0.0 (2021-09-24)
------------------

- Add Python 3.8/3.9 support
  [timo]

- Drop Python 2 support.
  [timo]

- Drop Plone 5 support.
  [timo]
- Add Italian translations.
  [cekk]


1.4.0 (2020-04-08)
------------------

- Remove maxlength parameter from seo fields.
  [timo]


1.3.0 (2020-03-24)
------------------

- Add Open Graph title, description and image.
  [timo]

- Add German translation.
  [timo]


1.2.1 (2020-01-16)
------------------

- Re-release 1.2.0.
  [timo]


1.2.0 (2020-01-16)
------------------

- Add canonical_url option.
  [timo]


1.1.0 (2020-01-10)
------------------

- Add noindex option.
  [timo]


1.0.0 (2019-05-14)
------------------

- Python 3 compatibility.
  [timo]

- Plone 5.2 compatibility.
  [timo]

- Remove unnecessary plone.directives.form test dependency.
  [timo]

- Use black formatter.
  [timo]


1.0.0a1 (2018-07-09)
--------------------

- Initial release.
  [kitconcept]
